gradoptics.integrator.stratified\_sampling\_integrator
==================================

.. automodule:: gradoptics.integrator.stratified_sampling_integrator
   :members:
   :undoc-members:
   :show-inheritance:
